@@ -18,16 +18,16 @@ sub _definition {
             'HEADER_FONT_STYLE'  => 'bf',
             'HEADER_CENTERED'    => 1,
             'CAPTION_FONT_STYLE' => 'bf',
-            'VERTICAL_LINES'     => [ 1, 2, 1 ],
-            'HORIZONTAL_LINES'   => [ 1, 2, 0 ],
+            'VERTICAL_RULES'     => [ 1, 2, 1 ],
+            'HORIZONTAL_RULES'   => [ 1, 2, 0 ],
             'BOOKTABS'           => 0,
         },
         'Houston' => {
             'HEADER_FONT_STYLE'  => 'bf',
             'HEADER_CENTERED'    => 1,
             'CAPTION_FONT_STYLE' => 'bf',
-            'VERTICAL_LINES'     => [ 1, 2, 1 ],
-            'HORIZONTAL_LINES'   => [ 1, 2, 1 ],
+            'VERTICAL_RULES'     => [ 1, 2, 1 ],
+            'HORIZONTAL_RULES'   => [ 1, 2, 1 ],
             'EXTRA_ROW_HEIGHT'   => '1pt',
             'BOOKTABS'           => 0,
         },
@@ -35,8 +35,8 @@ sub _definition {
             'HEADER_FONT_STYLE'  => 'bf',
             'HEADER_CENTERED'    => 1,
             'CAPTION_FONT_STYLE' => 'bf',
-            'VERTICAL_LINES'     => [ 1, 1, 1 ],
-            'HORIZONTAL_LINES'   => [ 1, 2, 0 ],
+            'VERTICAL_RULES'     => [ 1, 1, 1 ],
+            'HORIZONTAL_RULES'   => [ 1, 2, 0 ],
             'BOOKTABS'           => 0,
         },
         'Miami' => {
@@ -44,14 +44,14 @@ sub _definition {
             'HEADER_CENTERED'    => 1,
             'CAPTION_FONT_STYLE' => 'bf',
             'STUB_ALIGN'         => 'l',
-            'VERTICAL_LINES'     => [ 0, 0, 0 ],
-            'HORIZONTAL_LINES'   => [ 0, 1, 0 ],
+            'VERTICAL_RULES'     => [ 0, 0, 0 ],
+            'HORIZONTAL_RULES'   => [ 0, 1, 0 ],
             'BOOKTABS'           => 0,
         },
         'plain' => {
             'STUB_ALIGN'         => 'l',
-            'VERTICAL_LINES'   => [ 0, 0, 0 ],
-            'HORIZONTAL_LINES' => [ 0, 0, 0 ],
+            'VERTICAL_RULES'   => [ 0, 0, 0 ],
+            'HORIZONTAL_RULES' => [ 0, 0, 0 ],
             'BOOKTABS'         => 0,
         },
     };
